@@ -10,7 +10,7 @@ use 5.008000;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.10';
 
 require Exporter;
 
@@ -49,10 +49,24 @@ Crypt::OpenSSL::AES - A Perl wrapper around OpenSSL's AES library
 
      use Crypt::OpenSSL::AES;
 
-     my $cipher = new Crypt::OpenSSL::AES($key);
+     my $cipher = Crypt::OpenSSL::AES->new($key);
 
-     $encrypted = $cipher->encrypt($plaintext)
-     $decrypted = $cipher->decrypt($encrypted)
+     or
+
+     # Pick better keys and iv...
+     my $key = pack("H*", substr(sha512_256_hex(rand(1000)), 0, ($ks/4)));
+     my $iv  = pack("H*", substr(sha512_256_hex(rand(1000)), 0, 32));
+     my $cipher = Crypt::OpenSSL::AES->new(
+                                            $key,
+                                            {
+                                                cipher => 'AES-256-CBC',
+                                                iv      => $iv, (16-bytes for supported ciphers)
+                                                padding => 1, (0 - no padding, 1 - padding)
+                                            }
+                                        );
+
+     $encrypted = $cipher->encrypt($plaintext);
+     $decrypted = $cipher->decrypt($encrypted);
 
 =head1 DESCRIPTION
 
@@ -64,12 +78,67 @@ supports only AES 256 ECB (electronic codebook mode encryption).
 This module is compatible with Crypt::CBC (and likely other modules
 that utilize a block cipher to make a stream cipher).
 
-This module is an alternative to the implementation provided by 
+This module is an alternative to the implementation provided by
 Crypt::Rijndael which implements AES itself. In contrast, this module
 is simply a wrapper around the OpenSSL library.
 
+As of version 0.09 additional AES ciphers are supported.  Those are:
+
 =over 4
 
+=item AES-128-ECB, AES-192-ECB and AES-256-ECB (no IV)
+
+Supports padding
+
+=item AES-128-CBC, AES-192-CBC and AES-256-CBC
+
+Supports padding and iv
+
+=item AES-128-CFB, AES-192-CFB and AES-256-CFB
+
+Supports padding and iv
+
+=item AES-128-CTR, AES-192-CTR and AES-256-CTR
+
+Supports padding and iv
+
+=item AES-128-OFB, AES-192-OFB and AES-256-OFB
+
+Supports padding and iv
+
+=back
+
+=over 4
+
+=item new()
+
+For compatibility with old versions you can simply pass the key to the
+new constructor.
+
+    my $cipher = Crypt::OpenSSL::AES->new($key);
+
+    or
+
+    my $cipher = Crypt::OpenSSL::AES->new($key,
+                    {
+                        cipher  => 'AES-256-CBC',
+                        iv      => $iv, (16-bytes for supported ciphers)
+                        padding => 1, (0 - no padding, 1 - padding)
+                    });
+
+    # cipher
+    #   AES-128-ECB, AES-192-ECB and AES-256-ECB (no IV)
+    #   AES-128-CBC, AES-192-CBC and AES-256-CBC
+    #   AES-128-CFB, AES-192-CFB and AES-256-CFB
+    #   AES-128-CTR, AES-192-CTR and AES-256-CTR
+    #   AES-128-OFB, AES-192-OFB and AES-256-OFB
+    #
+    # iv - 16-byte random data
+    #
+    # padding
+    #   0 - no padding
+    #   1 - padding
+
 =item $cipher->encrypt($data)
 
 Encrypt data. The size of C<$data> must be exactly C<blocksize> in
@@ -95,7 +164,7 @@ but this method always returns 32 for Crypt::CBC's sake.
 =item blocksize
 
 This method is used by Crypt::CBC to check the block size.
-The blocksize for AES is always 16 bytes. 
+The blocksize for AES is always 16 bytes.
 
 =back
 
